@@ -7,12 +7,11 @@ expired certificate). Any performance degredation should be minor in most cases.
 """
 
 import click
-import click_config_file
 import keyring
 import requests
 import datetime, os, sys
 from urllib.parse import urlparse
-from ... import config
+from dataforge import config
 
 PROJECT_XML = {
     'content': 'project_xml',
@@ -44,21 +43,13 @@ def export_to_file(post_fields, url, token, outfile):
     with open(outfile, mode='wb') as f:
         f.write(response.content)
 
-def config_provider(file_path, cmd_name):
-    """Returns options found in configuration file(s)"""
-    settings = config['sources.redcap.api'].get()
-    if not settings:
-        settings = {}
-    return settings
-
-@click.command()
+@click.command(context_settings={'default_map':config['sources.redcap.api'].get()})
 @click.argument('url', envvar='REDCAP_URL')
 @click.option('--token', '-t', help='REDCap API token')
 @click.option('--project_name', '-p', envvar='REDCAP_PROJECT',
               help='REDCap project name abbreviation (no spaces)')
 @click.option('--outdir', '-o', envvar='REDCAP_OUTDIR', default='tmp/redcap',
               show_default=True)
-@click_config_file.configuration_option(provider=config_provider)
 def export(url, token, project_name, outdir):
     """Export data and metadata from REDCap project"""
     
